@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
 
+import sys
+
 from toot import api, config
 from toot.auth import login_interactive, login_browser_interactive, create_app_interactive
 from toot.exceptions import ConsoleError, NotFoundError
 from toot.output import (print_out, print_instance, print_account,
                          print_search_results, print_timeline, print_notifications)
-from toot.utils import assert_domain_exists, multiline_input, EOF_KEY
+from toot.utils import assert_domain_exists, editor_input, multiline_input, EOF_KEY
 
 
 def get_timeline_generator(app, user, args):
@@ -20,11 +22,15 @@ def get_timeline_generator(app, user, args):
         raise ConsoleError("The --instance option is only valid alongside --public or --tag.")
 
     if args.public:
-        instance = args.instance or app.instance
-        return api.public_timeline_generator(instance, local=args.local, limit=args.count)
+        if args.instance:
+            return api.anon_public_timeline_generator(args.instance, local=args.local, limit=args.count)
+        else:
+            return api.public_timeline_generator(app, user, local=args.local, limit=args.count)
     elif args.tag:
-        instance = args.instance or app.instance
-        return api.tag_timeline_generator(instance, args.tag, local=args.local, limit=args.count)
+        if args.instance:
+            return api.anon_tag_timeline_generator(args.instance, args.tag, limit=args.count)
+        else:
+            return api.tag_timeline_generator(app, user, args.tag, local=args.local, limit=args.count)
     elif args.list:
         return api.timeline_list_generator(app, user, args.list, limit=args.count)
     else:
@@ -46,7 +52,7 @@ def timeline(app, user, args):
 
         print_timeline(items)
 
-        if args.once:
+        if args.once or not sys.stdout.isatty():
             break
 
         char = input("\nContinue? [Y/n] ")
@@ -69,27 +75,36 @@ def thread(app, user, args):
     print_timeline(thread)
 
 
-def curses(app, user, args):
-    generator = get_timeline_generator(app, user, args)
-    from toot.ui.app import TimelineApp
-    TimelineApp(app, user, generator).run()
-
-
 def post(app, user, args):
+    # TODO: this might be achievable, explore options
+    if args.editor and not sys.stdin.isatty():
+        raise ConsoleError("Cannot run editor if not in tty.")
+
     if args.media and len(args.media) > 4:
         raise ConsoleError("Cannot attach more than 4 files.")
 
-    if args.media:
-        media = [_do_upload(app, user, file) for file in args.media]
-        media_ids = [m["id"] for m in media]
-    else:
-        media = None
-        media_ids = None
+    # Read any text that might be piped to stdin
+    if not args.text and not sys.stdin.isatty():
+        args.text = sys.stdin.read().rstrip()
 
-    if media and not args.text:
-        args.text = "\n".join(m['text_url'] for m in media)
+    # Match media to corresponding description and upload
+    media = args.media or []
+    descriptions = args.description or []
+    uploaded_media = []
 
-    if not args.text:
+    for idx, file in enumerate(media):
+        description = descriptions[idx].strip() if idx < len(descriptions) else None
+        result = _do_upload(app, user, file, description)
+        uploaded_media.append(result)
+
+    media_ids = [m["id"] for m in uploaded_media]
+
+    if uploaded_media and not args.text:
+        args.text = "\n".join(m['text_url'] for m in uploaded_media)
+
+    if args.editor:
+        args.text = editor_input(args.editor, args.text)
+    elif not args.text:
         print_out("Write or paste your toot. Press <yellow>{}</yellow> to post it.".format(EOF_KEY))
         args.text = multiline_input()
 
@@ -104,9 +119,14 @@ def post(app, user, args):
         spoiler_text=args.spoiler_text,
         in_reply_to_id=args.reply_to,
         language=args.language,
+        scheduled_at=args.scheduled_at,
+        content_type=args.content_type
     )
 
-    print_out("Toot posted: <green>{}</green>".format(response.get('url')))
+    if "scheduled_at" in response:
+        print_out("Toot scheduled for: <green>{}</green>".format(response["scheduled_at"]))
+    else:
+        print_out("Toot posted: <green>{}</green>".format(response.get('url')))
 
 
 def delete(app, user, args):
@@ -196,7 +216,7 @@ def activate(app, user, args):
 
 
 def upload(app, user, args):
-    response = _do_upload(app, user, args.file)
+    response = _do_upload(app, user, args.file, args.description)
 
     msg = "Successfully uploaded media ID <yellow>{}</yellow>, type '<yellow>{}</yellow>'"
 
@@ -212,9 +232,9 @@ def search(app, user, args):
     print_search_results(response)
 
 
-def _do_upload(app, user, file):
+def _do_upload(app, user, file, description):
     print_out("Uploading media: <green>{}</green>".format(file.name))
-    return api.upload_media(app, user, file)
+    return api.upload_media(app, user, file, description=description)
 
 
 def _find_account(app, user, account_name):
@@ -306,9 +326,22 @@ def notifications(app, user, args):
         print_out("<green>Cleared notifications</green>")
         return
 
-    notifications = api.get_notifications(app, user)
+    exclude = []
+    if args.mentions:
+        # Filter everything except mentions
+        # https://docs.joinmastodon.org/methods/notifications/
+        exclude = ["follow", "favourite", "reblog", "poll", "follow_request"]
+    notifications = api.get_notifications(app, user, exclude_types=exclude)
     if not notifications:
         print_out("<yellow>No notification</yellow>")
         return
 
+    if args.reverse:
+        notifications = reversed(notifications)
+
     print_notifications(notifications)
+
+
+def tui(app, user, args):
+    from .tui.app import TUI
+    TUI.create(app, user).run()
