@@ -1,8 +1,9 @@
+from html.parser import HTMLParser
 import re
 import shutil
 import subprocess
 
-from datetime import datetime
+from datetime import datetime, timezone
 
 HASHTAG_PATTERN = re.compile(r'(?<!\w)(#\w+)\b')
 
@@ -13,7 +14,7 @@ def parse_datetime(value):
     # In Python < 3.7, `%z` does not match `Z` offset
     # https://docs.python.org/3.7/library/datetime.html#strftime-and-strptime-behavior
     if value.endswith("Z"):
-        dttm = datetime.strptime(value, "%Y-%m-%dT%H:%M:%S.%fZ")
+        dttm = datetime.strptime(value, "%Y-%m-%dT%H:%M:%S.%fZ").replace(tzinfo=timezone.utc)
     else:
         dttm = datetime.strptime(value, "%Y-%m-%dT%H:%M:%S.%f%z")
 
@@ -74,3 +75,30 @@ def show_media(paths):
         raise Exception("Cannot find an image viewer")
 
     subprocess.run([viewer] + paths)
+
+
+class LinkParser(HTMLParser):
+
+    def reset(self):
+        super().reset()
+        self.links = []
+
+    def handle_starttag(self, tag, attrs):
+        if tag == "a":
+            href, title = None, None
+            for name, value in attrs:
+                if name == "href":
+                    href = value
+                if name == "title":
+                    title = value
+            if href:
+                self.links.append((href, title))
+
+
+def parse_content_links(content):
+    """Parse <a> tags from status's `content` and return them as a list of
+    (href, title), where `title` may be None.
+    """
+    parser = LinkParser()
+    parser.feed(content)
+    return parser.links[:]
